//////////////////////////////////////////////////
// profile.cpp: class which treat *.INI file 
//                                  for os2otp.exe
//                       (C) Hige no Shinshi, 1997

#define INCL_WIN
#define INCL_PM

#include <os2.h>
#include <stdio.h>

#include "os2otp.h"
#include "profile.h"

//////////////////////////////////////////////////
// StatusProfile's Constructor / Destructor
//
StatusProfile::StatusProfile()
{
    LoadProfile();
}
StatusProfile::~StatusProfile()
{
    SaveProfile();
    if (m_szParams != NULL)
        delete [] m_szParams;
}
//////////////////////////////////////////////////
// LoadProfile(): load setting from *.ini file
//
void StatusProfile::LoadProfile()
{
    PSZ szIniName = (PSZ) new CHAR[strlen(szAppName)+4+1];
    sprintf(szIniName, "%s.ini", szAppName);
    HINI hIni = PrfOpenProfile(hab, szIniName);
    delete [] szIniName;

    if (hIni == NULLHANDLE) {
        SetHashAlg(MD4);
        SetAppendStr(NULL);
        SetDispWord(TRUE);
        SetAutoDecrement(TRUE);
        m_szParams = NULL;
    } else {
        ULONG dwSize;
        BOOL rc;
        dwSize = sizeof (UINT);
        rc = PrfQueryProfileData(hIni, szAppName, "HashAlg",
                                 &m_nHashAlg, &dwSize);
        if (!rc)
            m_nHashAlg = MD4;
        
        dwSize = sizeof (UINT);
        rc = PrfQueryProfileData(hIni, szAppName, "AppendStr",
                                 &m_nAppendStr, &dwSize);
        if (!rc)
            m_nAppendStr = NULL;

        dwSize = sizeof (BOOL);
        rc = PrfQueryProfileData(hIni, szAppName, "DispWord",
                                 &m_bDispWord, &dwSize);
        if (!rc)
            m_bDispWord = TRUE;
        
        dwSize = sizeof (BOOL);
        rc = PrfQueryProfileData(hIni, szAppName, "AutoDecrement",
                                &m_bAutoDecrement, &dwSize);
        if (!rc)
            m_bAutoDecrement = FALSE;
        
        dwSize = sizeof (POINTL);
        rc = PrfQueryProfileData(hIni, szAppName, "POINT",
                            &m_pt, &dwSize);
        if (!rc){
            m_pt.x = 100;
            m_pt.y = 100;
        }
        PrfQueryProfileSize(hIni, szAppName, "Params", &dwSize);
        m_szParams = (PSZ)new UCHAR[dwSize];
        PrfQueryProfileString(hIni, szAppName, "Params",
                              "", m_szParams, dwSize);

        PrfCloseProfile(hIni);
    }
}
//////////////////////////////////////////////////
// SaveProfile(): save setting to *.ini file
//
void StatusProfile::SaveProfile()
{
    PSZ szIniName = (PSZ) new CHAR[strlen(szAppName)+4+1];
    sprintf(szIniName, "%s.ini", szAppName);
    HINI hIni = PrfOpenProfile(hab, szIniName);
    delete [] szIniName;
    if (hIni != NULLHANDLE) {
        PrfWriteProfileData(hIni, szAppName, "HashAlg",
                            &m_nHashAlg, sizeof (UINT));
        
        PrfWriteProfileData(hIni, szAppName, "AppendStr",
                            &m_nAppendStr, sizeof (UINT));

        PrfWriteProfileData(hIni, szAppName, "DispWord",
                            &m_bDispWord, sizeof (BOOL));

        PrfWriteProfileData(hIni, szAppName, "AutoDecrement",
                            &m_bAutoDecrement, sizeof (BOOL));

        PrfWriteProfileData(hIni, szAppName, "POINT",
                            &m_pt, sizeof (POINTL));

        PrfWriteProfileString(hIni, szAppName,  "Params", m_szParams);

        PrfCloseProfile(hIni);
    }
}
//////////////////////////////////////////////////
// SetParams(): set parameter string
//
void StatusProfile::SetParams(PSZ szParams)
{
    if (m_szParams != NULL) {
        delete [] m_szParams;
    }
    m_szParams = (PSZ) new CHAR[strlen(szParams)+1];
    strcpy(m_szParams, szParams);
}
//////////////////////////////////////////////////
// QueryHashAlgName(): query current hash algorithm
//
PCSZ StatusProfile::QueryHashAlgName()
{
    switch (m_nHashAlg) {
    case MD4:
        return "MD4";
    case MD5:
        return "MD5";
    case SHA1:
        return "SHA1";
    default:
        return NULL;
    }
    /* not reached */
}
//////////////////////////////////////////////////
// QueryAppendStrStr(): query current append string
//
PCSZ StatusProfile::QueryAppendStrStr()
{
    switch (m_nAppendStr) {
    case NULL:
        return "";
    case CR:
        return "\r";
    case LF:
        return "\n";
    default:
        return NULL;
    }
    /* not reached */
}
